@@ -3,7 +3,7 @@ package Path::Dispatcher;
 use Moose;
 use MooseX::AttributeHelpers;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Path::Dispatcher::Rule;
 use Path::Dispatcher::Dispatch;
@@ -34,12 +34,6 @@ has _rules => (
     },
 );
 
-has super_dispatcher => (
-    is        => 'rw',
-    isa       => 'Path::Dispatcher',
-    predicate => 'has_super_dispatcher',
-);
-
 sub dispatch {
     my $self = shift;
     my $path = shift;
@@ -54,9 +48,6 @@ sub dispatch {
         );
     }
 
-    $dispatch->add_redispatches($self->redispatches($path))
-        if $self->can_redispatch;
-
     return $dispatch;
 }
 
@@ -72,15 +63,6 @@ sub dispatch_rule {
     return 1;
 }
 
-sub can_redispatch { shift->has_super_dispatcher }
-
-sub redispatches {
-    my $self = shift;
-    my $path = shift;
-
-    return $self->super_dispatcher->dispatch($path)
-}
-
 sub run {
     my $self = shift;
     my $path = shift;
@@ -119,14 +101,14 @@ Path::Dispatcher - flexible dispatch
     my $dispatcher = Path::Dispatcher->new;
 
     $dispatcher->add_rule(
-        Path::Dispacher::Rule::Regex->new(
+        Path::Dispatcher::Rule::Regex->new(
             regex => qr{^/(foo)/},
             block => sub { warn $1; }, # foo
         )
     );
 
     $dispatcher->add_rule(
-        Path::Dispacher::Rule::Tokens->new(
+        Path::Dispatcher::Rule::Tokens->new(
             tokens    => ['ticket', 'delete', qr/^\d+$/],
             delimiter => '/',
             block     => sub { delete_ticket($3) },
@@ -146,6 +128,9 @@ rules, and it returns a list of matches. From there you can "run" the rules
 that matched. These phases are distinct so that, if you need to, you can
 inspect which rules were matched without ever running their codeblocks.
 
+Most consumers would want to use L<Path::Dispatcher::Declarative> which gives
+you some sugar inspired by L<Jifty::Dispatcher>.
+
 =head1 ATTRIBUTES
 
 =head2 rules
@@ -157,15 +142,6 @@ A list of L<Path::Dispatcher::Rule> objects.
 A human-readable name; this will be used in the (currently nonexistent)
 debugging hooks.
 
-=head2 super_dispatcher
-
-Another Path::Dispatcher to defer to when no rules match in the current
-dispatcher. This is intended for "subclassing" dispatchers, such as when you
-have a framework dispatcher and an application dispatcher.
-
-WARNING: The super dispatcher feature is currently unstable. I'm still trying
-to figure out the right way to have them.
-
 =head1 METHODS
 
 =head2 add_rule
@@ -193,6 +169,20 @@ Please report any bugs or feature requests to
 C<bug-path-dispatcher at rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Path-Dispatcher>.
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Jifty::Dispatcher>
+
+=item L<Catalyst::Dispatcher>
+
+=item L<Mojolicious::Dispatcher>
+
+=item L<Path::Router>
+
+=back
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 Best Practical Solutions.
